@@ -14,13 +14,19 @@ class Firebase(object):
 		cred = credentials.Certificate(key) # must still be edited through env variables.
 		firebase_admin.initialize_app(cred)
 		self.firestore = FireStore()
-		self.users = Users()
+		self.users = Users(firestore=self.firestore)
 
 		#
 
 # the users class.
 class Users(object):
-	def __init__(self):
+	def __init__(self, firestore=None):
+
+		# objects.
+		self.firestore = firestore
+
+		# settings for saving user data.
+		self.users_collection = "users/"
 
 		# the settings for sending emails.
 		self.email_address = None
@@ -128,11 +134,6 @@ class Users(object):
 		email_verified=None,
 	):
 
-		# check parameters.
-		response = r3sponse.check_parameters(empty_value=None, parameters={
-			"uid":uid,
-		})
-
 		# load.
 		response = self.get(uid=uid, email=email)
 		if response["error"] != None: return response
@@ -300,6 +301,24 @@ class Users(object):
 			return r3sponse.success_response("Successfull verification.")
 
 		#
+	def load_data(self,
+		# the user's uid.
+		uid=None,
+	):
+		response = self.firestore.load(f"{self.users_collection}/{uid}/")
+		if response["error"] != None: return response
+		return r3sponse.success_response(f"Successfully loaded the data of user [{uid}].", {
+			"data":response["document"],
+		})
+	def save_data(self,
+		# the user's uid.
+		uid=None,
+		# the user's data.
+		data={},
+	):
+		response = self.firestore.save(f"{self.users_collection}/{uid}/", data)
+		if response["error"] != None: return response
+		return r3sponse.success_response(f"Successfully saved the data of user [{uid}].")
 	# system functions.
 	def __initialize_email__(self):
 		# the email object.
